@@ -9,5 +9,11 @@ class Cwe(BaseModel):
     name = db.Column(db.String())
     description = db.Column(db.String())
 
+    @property
+    def short_id(self):
+        if not self.cwe_id.startswith("CWE-"):
+            return None
+        return self.cwe_id.split("CWE-")[1]
+
     def __repr__(self):
         return "<Cwe {}>".format(self.cwe_id)
